@@ -21,7 +21,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wait waitpid waitall TIMEOUT WREAP_BG_OK);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.63';
+our $VERSION = '0.64';
 
 my ($productive_waitpid_code);
 my $respect_SIGCHLD_ignore = 1;
@@ -46,7 +46,8 @@ sub wait {
 	$timeout = _BRIEF_TIMEOUT;
     }
     debug('invoked Forks::Super::wait') if $DEBUG;
-    return Forks::Super::Wait::waitpid(-1, 0, $timeout);
+    my $x = Forks::Super::Wait::waitpid(-1, 0, $timeout);
+    return $x;
 }
 
 sub _cleanse_waitpid_args {
